#
# spec file for package rtags
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rtags
Version:        2.38
Release:        3.6
Summary:        Clang based source code indexer
License:        GPL-3.0-or-later
Group:          Development/Tools/Navigators
URL:            https://github.com/Andersbakken/rtags
Source0:        https://github.com/Andersbakken/rtags/releases/download/v%{version}/rtags-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM rtags-2.38-emacs-28.patch -- Fix build with Emacs 28
Patch0:         rtags-2.38-emacs-28.patch
BuildRequires:  clang-devel
BuildRequires:  cmake
BuildRequires:  emacs-nox
BuildRequires:  gcc-c++
BuildRequires:  llvm-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)

%description
Rtags is Clang based source file indexer supporting C/C++/Objective-C(++) code.

%define _sitedir %{_datadir}/emacs/site-lisp
%define _scriptdir %{_datadir}/rtags/

%prep
%autosetup -p1

%build
%cmake \
  -DCURSES_CURSES_LIBRARY:FILEPATH="%{_libdir}/libncurses.so"
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_sitedir} %{buildroot}%{_scriptdir}
install -m 0755 -t %{buildroot}%{_scriptdir} bin/*.sh
chmod 0755 %{buildroot}%{_bindir}/gcc-rtags-wrapper.sh

%files
%doc README.org CHANGELOG
%license LICENSE.txt
%{_bindir}/rdm
%{_bindir}/rc
%{_bindir}/rp
%{_bindir}/gcc-rtags-wrapper.sh
%{_mandir}/man7/rc.7%{?ext_man}
%{_mandir}/man7/rdm.7%{?ext_man}
%{_sitedir}/rtags
%{_scriptdir}

%changelog
* Sat Jun 25 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add rtags-2.38-emacs-28.patch: Fix build with emacs 28.
* Sat Jan  2 2021 Cameron Rapp <camspam@redhyena.net>
- Update obsolete BuildRequires: llvm-clang-devel -> clang-devel.
* Tue Sep 22 2020 Martin Liška <mliska@suse.cz>
- Update to 2.38
  * see packaged CHANGELOG file or
    https://github.com/Andersbakken/rtags/blob/v2.38/CHANGELOG
* Fri Sep 27 2019 Martin Pluskal <mpluskal@suse.com>
- Update dependencies
- Use more modern macros
* Thu Sep 26 2019 Adam Mizerski <adam@mizerski.pl>
- update to 2.34
  * see packaged CHANGELOG file or
    https://github.com/Andersbakken/rtags/blob/v2.34/CHANGELOG
- use release tarball instead of checking out git
* Fri Mar  8 2019 mliska@suse.cz
- Update to version 2.22+git.20190304.c4dea899:
  * Bump version to 2.22
  * Make diagnostics completions enabled by default. They seem to work and are way way faster.
  * Hopefully fix #1299
  * Fix shadowing.
  * Kill inclusionError concept. Not really used anymore anyway.
  * Capture assembly output
  * Fix warning on clang 9
  * Convert cc_prefix.sh and gcc-rtags-hook.sh to POSIX sh
  * Ensure that the project path always has a trailing slash
  * Fix warning.
  * Fix warning.
  * Bump rct.
  * This doesn't exist.
  * Add missing newline character after printing server options
  * Do not explicitly validate the project while it's still indexing (#1286)
  * Consider all other unsaved files when code completing a given file
  * Consider unsaved files when reindexing to recover from #include errors
  * Add support to --remove for removing all files in compile_commands.json
  * Support regex matching in the argument to --is-indexing
  * Documentation is now available in the wiki
  * Output #include/break/continue/return symbol targets for JSON and Elisp
  * Do not remove characters from the display name of FieldDecl symbols
  * [man] Update man pages
  * Add support to --is-indexing for checking against a single project
  * [travis] Find llvm-config using find
  * [lisp] Add customizable user option variables for rc and rdm binary
  * Fix #1262: Append llvm-config --system-libs to LIBCLANG_LIBRARIES
  * Create annotated release tags
  * Bump version to 2.21
  * Push commits and tags when bumping version
  * [lisp] Use correct new url in `rtags-install` to fetch artifacts
  * Update changelog
  * [rtags] Add back unintentional removed lines from 34c63a3
  * [travis] Use GCC 7 for GNU/Linux travis build
  * [rtags] Fix warnings from newer compiler versions
  * [rct] Update json.hpp to fix warnings
  * [travis] Run unittests on OSx again
  * [rct] Fix warnings from submodule
  * Run Completion test on GNU/Linux again
  * Verify output commands with whitespaces with any order
  * Update and fix CI builds
  * Change xrange to range
  * [test_runner.py] FileNotFoundError is not available in python 2.7
  * Completion should not show NotAccessible items
  * Improve functions doc string
  * Fix `rtags-find-file' no working for remote locations
  * Fix bug introduced in 6aa45cb37
  * make rtags-install work with tramp locations
  * Better alignment.
  * Make rtags-find-dead-functions work from elisp.
  * Shorten --verify-version since it's passed on every call from elisp.
  * Update README; rtags-diagnostics is not required for completion
  * Fix #1247 Don't enable `rtags-diagnostics` by default on `ac-init`
  * rtags-trampify chokes when run run on emacs 25.3.1
  * rtags: Initial support for DragonFly BSD
  * Do not display diagnostics when indexing files in the completion thread
  * Do not print an error message for a null symbol that is a file symbol
  * Revert fix for iOS travis build from 37fafe6
  * Bump rct
  * Use --strip-paren to exclude function variables from --find-symbols
  * Make --match-icase apply to --match-regexp
  * Make --max option apply to the output from --code-complete-at
  * Handle skipped diagnostic before a new empty entry for it can be added to the checkStyle map (operator[] creates a new entry). The empty entries showed up in the output with the message set to "null".
  * Rephrase message when compiler without c++11 regex support was detected
  * Bump rct
  * RTags CI/CD setup
  * Remove fix-dylib.sh and git-archive-all scripts
  * Add CHANGELOG file
  * Includes.
  * Added RTagsComplete to Sublime Text plugins.
  * Update release notes.
  * Push tag right here.
  * Bump version to 2.20
  * WatchSourcesOnly isn't meant to filter out compile_commands.json changes.
  * Work on reloadCompileCommands stuff. Most importantly it seems like we lost the watch on the compile_commands after it had been a target for a rename and this has caused endless grief over the last couple of years. No reason to watch the file explicitly really so we now watch the directory. Also, periodically check the dirtiness of the project to insulate against similar bugs.
  * Bump rct.
  * Sanity check that fils really have been removed before removing them.
  * Dump info about all projects' filesystem watches.
  * Do this in a timer as well.
  * Oops.
  * Try to fix build for emacs < 25.
  * Dump emacs version.
  * Use correct environment variable for config path
  * Fix typo d2b10d624
  * Start groundwork for making it possible to run rp in a thread
  * loose the warning. Kinda silly.
  * apparently this isn't okay.
  * elisp warnings
  * Opt-in for completion thread diagnostics.
  * Refactor automated test runner
  * Warning.
  * Clean up these scopes.
  * don't do this for headers
  * Try to suppress validation errors during indexing
  * Bump rct.
  * Don't expose non-default.
  * Actually use diagnostics from completion thread. It seems very fast.
  * Make sure we don't mix and match rdm runs with and without --no-realpath
  * Bump rct.
  * Compile in debug.
  * This is an awful hack.
  * Bump rct
  * Bump rct
  * Fall through
  * Not used.
  * Fix issue #984 properly. Supply our own tempdir under $TMPDIR and clean it out on startup of rdm as well as make subdirs for each rp.
  * Remove header error stuff. It never made anything work better.
  * Clean up after ourselves.
  * Bump rct
  * Typo.
  * Release notes.
  * Generate man pages
  * Bump version to 2.19
  * Remove some dead functions (Found with rc --find-dead-functions)!
  * Fix issue #1152. Find dead functions.
  * Don't use stdin for processes. It seems to be slow. Use tempfile that rc reads instead.
  * Bump rct.
  * Compare the right length
  * Move this.
  * Better logging for completion.
  * Might as well have this even if it isn't used.
  * I think this is more useful output.
  * Macro_Definition should be higher it seems.
  * Make this work again somewhat.
  * This seems to crash.
  * Clang has https now!
  * Some cleanup with flags etc with rtags log outputs and whatnot.
  * Fix issue #1209.
  * Additional logging.
  * This is a novalue define.
  * Fix issue #1214. No need to resolve the socket file. It's never compared as a string or give a fileid.
  * Try to be more silent about these warnings. They are innocuous.
  * Put actual license text in LICENSE.txt
  * Fix #1129
  * Use info as level for fixits in flycheck-rtags.el
  * replace auto with the type if possible.
  * Fixed an issue with code completion.
  * Bump rct
  * Fix compile warning "maybe uninitialized"
  * Fix _FORTIFY_SOURCE warnings in Debug build
  * cmake: Only set property if test target was set up
  * Fix test ForwardDeclaration:forward_declared_object_points_to_real_declaration_through_macro
  * Rename automated_tests to automated, and move manual tests to manual dir
  * Move directory automated_tests to tests directory
  * Add test for #1053
  * Refactore test scripts and improve
  * Watch here too.
  * Change configure script flag --build-tests to --without-tests
  * Check for extended regex support at compile time.
  * simplify preservation of `compile-command' in `rtags-compile-file'
  * quote parentheses used in the regexp in `rtags-compile-file'
  * Search for perl using find_package
  * Exclude "skipped" diagnostics from rc's JSON output
  * Update man pages
  * Remove debug steps from travis.sh
  * Fix CI and target test setup
  * Bump rct
  * fixed sandbox-root regression due to encodeUrlComponent
  * Subtract one from the error column
  * Add issue template for feature requests
  * Increase minimum required version of GCC (4.9) and Emacs (24.3)
  * Use equal to compare return code of rc calls
  * Issue template work
  * Add a note about tests.
  * Dump sizeof in dump.
  * Fix #1189
  * Formatting
  * Attempt to support fisk.
  * Update issue templates
  * Fix tramp #1188 #1186
  * Print more descriptive message when clang sample app could no be compiled
  * Fix error with newer Tramp versions
  * Fixed max-depth issues.
  * Fixed some of the recursion depth issues.
  * Fix typo regarding bash completions configuration
  * Adding imenu index function.
  * Bump lisp version for --last-indexed rc option
  * Add `--last-indexed` rc command giving last idle time of current project
  * Roll back yesterday's changes. They seem to break stuff. I will revisit
  * Bump rct
  * Fix some issues running with --no-realpath
  * Bump rct.
  * Don't realpath in client.
  * use extended POSIX regex for matching ranges
  * bump rct
  * bump rct
  * Look harder for llvm-config
  * Fix issue #1168. Honor blocked arguments for preprocessor.
  * Fix inverted logic. This could lead to diagnostics with type === 'none which seems to happen sometimes.
  * Print priority in -s jobs
  * Fix issue #1165.
  * Need this.
  * Fix: reparse when saved file has changed
  * Compile with lua
  * More rtags-like API.
  * Added RTags::getArguments() to retrieve the function arguments.
  * Make it possible to customize completing-read behavior by changing rtags-completing-read-behavior
  * Fix issue 1160
  * add test
  * indent
  * It's already there apparently
  * Tests are always enabled.
  * Dump the packages.
  * pip is not a separate package.
  * Fewer tests.
  * Hacking away.
  * Lets try to fix this.
  * Bump rct.
  * More  test work
  * Move StringTokenizer and StringTokenizerTests.cpp to rct.
  * Is this better.
  * Run make test instead.
  * Ignore these .
  * This should help with the tests on travis.
  * Typo
  * Kill CMakeCache.txt on reconfigure
  * fixed scoping on an ifdef
  * Mention new neo-rtags neovim client for Rtags.
  * Fix issue #1150.
  * Ignore and bump
  * Bump rct.
  * Build rct_tests
  * Bump rct.
  * Actually set the socket write buffer max.
  * Install yarn and pip
  * Fix T
  * Try to move to 5.0
  * Try to move to 6.0.
  * More attempts.
  * Add packages
  * Any clang will do.
  * And maybe this.
  * Add version.
  * More attempts
  * try to make it work again
  * Oops. Don't overwrite other diagnostics.
  * Unionize skipped ranges for multibuilds.
  * Bump rct.
  * rtags.el: Add key binding and menu item for rtags-reference-tree
  * rtags.el: rename face, error customization, prompting, and scopes
* Sat Sep 22 2018 mliska@suse.cz
- Update to version 2.18.1+git.20180909.ce3bdfd9:
  * Fix typo d2b10d624
  * Start groundwork for making it possible to run rp in a thread
  * loose the warning. Kinda silly.
  * apparently this isn't okay.
  * elisp warnings
  * Opt-in for completion thread diagnostics.
  * Refactor automated test runner
  * Warning.
  * Fixed max-depth issues.
  * Fixed some of the recursion depth issues.
  * Adding imenu index function.
* Sat Feb  3 2018 mliska@suse.cz
- Update to version 2.18+git.20180130.98d668e8:
  * Bump version to 2.18
  * Roll back this one.
  * Fix warning.
  * trigger this on ctest.
  * Try this.
  * Fix package name.
  * Maybe like this?
  * Try to add more compilers.
  * Remove unused capture part deux.
  * Remove unused capture.
* Sun Aug 27 2017 mliska@suse.cz
- Update to version 2.13+git.20170825.93b00636:
  * Biump rct.
  * Not used.
  * grammar
  * Fix issue #1031. Detect if json.h is supported or not and turn off json output for completions if it isn't.
  * Kill previous rtags-find-symbol-at-point buffer if there is one.
  * Fix issue with the following example:
  * Fix an issue with this construct:
  * Bump database.
  * Bump version
  * Fix issue #1035 and issue #1035.
* Fri Mar  3 2017 mpluskal@suse.com
- Update to version 2.8+git.20161226.6ac7740e:
  * Bump db.
  * Use operator!= operator== for CXCursor
  * jobs doesn't depend on current project.
  * Oops. This needs to go before the break.
  * Refactor some cursor stuff.
  * Bump rct.
  * Handle multiple targets better.
  * Nicer dump for template specializations.
  * Work on template refs
  * Remove debugging.
* Wed Nov  2 2016 mpluskal@suse.com
- Update to version 2.3+git.20161031.767f76b:
  * Fix issue #826. Don't put: int => int etc for autos.
  * Avoid TypeRef refs to classes/structs.
  * Fix shadow warnings.
  * Apparently clang_getCanonicalType is all I really need for resolving autos. Or so it seems.
  * Apparently mLastCursor may be in a file we're not visiting.
  * Use the right argument. Make fixits work again.
  * Better error for handleInclude failures.
  * Add "brew services start rtags" to readme
  * resolve symlinks when updating the diagnostics buffer
  * Add something about rtags helm support in the readme.
- Update service
  * Use naming scheme containing latest release and commit date and
    commit id
  * Disable service by default to avoid unnecessary executions
* Mon Nov  9 2015 sleep_walker@opensuse.org
- bump to new git snapshot 83a40d0, 2015-11-09
  - it fixes missing librct problem
- wipe unused files
  generate-tarball.sh
  rtags-2.0.tar.gz
- add emacs-nox and gcc-c++ into dependencies
* Thu Sep 17 2015 sleep_walker@opensuse.org
- let there be rtags package!
